
class Translation(object):
    def __init__(self):
        self.androidKey = None
        self.iosKey = None
        self.comment = None
        self.groupComment = None
        self.translations = []




import os

from googlesheettranslate.main import GoogleTranslationSheet

ROOT = os.path.join(os.path.dirname(__file__))
builder = GoogleTranslationSheet().builderOutputTarget(ROOT).builderFromExcel("emp-translation.xlsx")
builder.builderTransformers("i18n")
builder.GetReader().overrideFileFormat("__i{}.json", True)
builder.run("EN")
builder.run("ZH")



# !/usr/bin/env python
# -*- coding: utf-8 -*-
# pylint: disable=C0116,W0613
# This program is dedicated to the public domain under the CC0 license.

import csv
import os

import requests
from bs4 import BeautifulSoup

from .x import Reader
from .x.Err import WrongReaderType

statement = 'End : {}, IO File {}'

CVS, GOOGLE_SHEET, CSV, EXCEL = range(4)


class GoogleTranslationSheet:
    """
    featured translation service does not need to use creditentials
    """

    headers = {
        'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.12; rv:79.0) Gecko/20100101 Firefox/79.0',
        'Accept-Language': 'en-US,en;q=0.5',
        'X-Requested-With': 'XMLHttpRequest'
    }

    proxies = {
        "http": "socks5://127.0.0.1:1086",
        "https": "socks5://127.0.0.1:1086",
    }

    def __init__(self):
        self.exportedSheetUrl = ""
        self.html = ""
        self.tab = ""
        self.engine_name = ""
        self.target_folder = ""
        self.input_filepath = ""
        self.tab_content = dict()
        self.saveToCvs = True
        self._reader_type = 0
        self.reader_debug = False
        self._use_proxies = False
        self._readerEngine = Reader()

    def EnabledProxy(self, replaces: dict = None) -> "GoogleTranslationSheet":
        self._use_proxies = True
        if replaces is not None:
            self.proxies = replaces
        return self

    def builderCvs(self, enabled: bool) -> "GoogleTranslationSheet":
        """
        enable CVS file save to the local path
        :param enabled:
        :return:
        """
        self.saveToCvs = enabled
        return self

    def builderOutputTarget(self, tar: str) -> "GoogleTranslationSheet":
        """
        save files at the specific target folder
        :param tar:
        :return:
        """
        self.target_folder = tar
        return self

    def builderTransformers(self, engine_name: str) -> "GoogleTranslationSheet":
        """
        using the transform engine from the specification tool
        :param engine_name:
        :return:
        """
        self.engine_name = engine_name
        return self

    def builderReaderDebug(self, de: bool) -> "GoogleTranslationSheet":
        """
        given the extra log detail to the reader
        :param de: yes or no
        :return:
        """
        self.reader_debug = de
        return self

    def builderReader(self, module_reader: Reader) -> "GoogleTranslationSheet":
        """
        building reader module by external instance
        :param module_reader:
        :return:
        """
        self._readerEngine = module_reader
        return self

    def builderFromCVS(self, filename: str = "") -> "GoogleTranslationSheet":
        """
        CVS file started
        :param filename:
        :return:
        """
        self.input_filepath = filename
        self._reader_type = CVS
        return self

    def builderFromCSV(self, filename: str = "") -> "GoogleTranslationSheet":
        """
        CVS file started
        :param filename:
        :return:
        """
        self.input_filepath = filename
        self._reader_type = CSV
        return self

    def builderFromExcel(self, filename: str = "") -> "GoogleTranslationSheet":
        """
        CVS file started
        :param filename:
        :return:
        """
        self.input_filepath = filename
        self._reader_type = EXCEL
        return self

    def builderFromGoogleSheet(self, url: str, tabname: str = "") -> "GoogleTranslationSheet":
        """
        this is the required for the basic meta information for loading google sheet
        :param url:
        :param tabname:
        :return:
        """
        self.exportedSheetUrl = url
        self.tab = tabname
        self._reader_type = GOOGLE_SHEET
        return self

    def builderFromGoogleSheetMeta(self, sheetID: str = "", gridID: str = "", tabg: str = "") -> "GoogleTranslationSheet":
        """
        building by the sheet IDs
        :param sheetID:
        :param gridID:
        :param tabg:
        :return:
        """
        self.exportedSheetUrl = f"https://docs.google.com/spreadsheets/d/e/{sheetID}/pubhtml?gid={gridID}&single=true"
        self.tab = tabg
        self._reader_type = GOOGLE_SHEET
        return self

    def GetReader(self) -> Reader:
        """
        make modification setting for the internal Reader instance
        :return:
        """
        return self._readerEngine

    def getFileNameInternal(self, index: int) -> str:
        """
        get the naming for the cvs file
        :param index:
        :return:
        """
        return os.path.join(self.target_folder, f"data{str(index)}.cvs")

    def _run_csv(self, Lang="CN") -> None:
        """
        read the cvs now
        :return:
        """
        if self._reader_type != CSV:
            raise WrongReaderType("You have not set proper csv file path for the translation source.")

        self._readerEngine.newSheet()
        self._readerEngine.setLang(Lang)

        with open(self.input_filepath, newline='') as csvfile:
            line_ex = csv.reader(csvfile, delimiter=',', quotechar='|')
            self.tab_content = [[y for y in row] for row in line_ex]
            self._readerEngine.setDebug(self.reader_debug).setTarget(self.target_folder).useEngine(
                self.engine_name).LoopMatrix(self.tab_content)

    def _run_excel(self, Lang="CN") -> None:
        if self._reader_type != EXCEL:
            raise WrongReaderType("You are not using excel.")
        self._readerEngine.newSheet()
        self._readerEngine.setLang(Lang)
        self._readerEngine.setDebug(self.reader_debug).setTarget(self.target_folder).useEngine(
            self.engine_name).LoopExcel(self.input_filepath)

    def _run_cvs(self, Lang="CN") -> None:
        """
        read the cvs now
        :return:
        """
        if self._reader_type != CVS:
            raise WrongReaderType("You have not set proper cvs file path for the translation source.")

        self._readerEngine.newSheet()
        self._readerEngine.setLang(Lang)

        with open(self.input_filepath, newline='') as csvfile:
            line_ex = csv.reader(csvfile, delimiter=' ', quotechar='|')
            line_lis = list()
            for row in line_ex:
                if len(row) == 0:
                    continue

                blist = row[0].split(",")
                newb = []
                for h in blist:
                    newb.append(self._process_s(h))
                print(newb)

                line_lis.append(newb)

            self.tab_content = line_lis

            # self.tab_content = [map(lambda x: self._process_s, line_lis)]
            self._readerEngine.startRow(0).setDebug(self.reader_debug).setTarget(self.target_folder).useEngine(
                self.engine_name).LoopMatrix(self.tab_content)

    def _process_s(self, string: str) -> str:
        if string.startswith('"'):
            string = string[1:]

        if string.endswith('"'):
            string = string[:-1]
        return string

    def _run_google_url(self, Lang="CN") -> None:
        """
                run up the engine for given parameters
                :param proxies: whether the connection is using VPN or no
                :param Lang: the language column that matched to the sheet
                :return:
                """

        if self._reader_type != GOOGLE_SHEET:
            raise WrongReaderType("You have not set proper google sheet url for the translation source.")
        self._readerEngine.newSheet()
        self._readerEngine.setLang(Lang)
        if self._use_proxies is True:
            self.html = requests.get(self.exportedSheetUrl, headers=self.headers, proxies=self.proxies).text
        else:
            self.html = requests.get(self.exportedSheetUrl, headers=self.headers).text

        soup = BeautifulSoup(self.html, "lxml")
        tables = soup.find_all("table")
        index = 0

        for table in tables:
            output_f = self.getFileNameInternal(index)
            self.tab_content = [[td.text for td in row.find_all("td")] for row in table.find_all("tr")]
            if self.saveToCvs:
                with open(output_f, "w") as f:
                    wr = csv.writer(f, quoting=csv.QUOTE_NONNUMERIC)
                    wr.writerows(self.tab_content)

            self._readerEngine.setDebug(self.reader_debug).setTarget(self.target_folder).useEngine(
                self.engine_name).LoopTable(self.tab_content)

            index = index + 1

    def run(self, Lang="CN"):
        if self._reader_type == CVS:
            self._run_cvs(Lang)
        elif self._reader_type == CSV:
            self._run_csv(Lang)
        elif self._reader_type == GOOGLE_SHEET:
            self._run_google_url(Lang)
        elif self._reader_type == EXCEL:
            self._run_excel(Lang)
        else:
            raise WrongReaderType("Incomplete source set.")



import socket
import sys

import gspread
import socks
# TODO: oauth2client is deprecated. Use recommended google-auth
from oauth2client.service_account import ServiceAccountCredentials

from googlesheettranslate.googlesheettech.Common import *
from googlesheettranslate.googlesheettech.modu.Spreadsheet import Spreadsheet
from googlesheettranslate.googlesheettech.cartrige.Android import *
from googlesheettranslate.googlesheettech.cartrige.IOS import *

USAGE = """
Usage: {0} /path/to/google_credentials.json SPREADSHEET_NAME TARGET
    
    SPREADSHEET_NAME
        If it contains whitespaces, use '' around the name.

    TARGET
        Valid options are: 'android', 'ios', 'ios-swift'
"""

# Make sure we have all necessary parameters specified at command line.
if (len(sys.argv) < 4):
    print(USAGE.format(sys.argv[0]))
    sys.exit(1)
# Parse command line arguments.
credentialsFileName = sys.argv[1]
documentName = sys.argv[2]
targetName = sys.argv[3]

socks.set_default_proxy(socks.SOCKS5, '127.0.0.1', 1086)
socket.socket = socks.socksocket

print("Connecting to Google Sheets API")
scope = ["https://spreadsheets.google.com/feeds"]
credentials = ServiceAccountCredentials.from_json_keyfile_name(credentialsFileName, scope)
client = gspread.authorize(credentials)

print("Opening spreadsheet")
spreadsheet = Spreadsheet(client)
spreadsheet.open(documentName)

print("Reading configuration page")
cfgPage = spreadsheet.sheet("CFG")
cfg = configurationFromPage(cfgPage)

print("Reading source page")
srcPage = spreadsheet.sheet("SRC")
(languages, translations) = parsePage(srcPage, cfg)

print("Found languages: '{0}'".format(languages))

if targetName == "android":
    androidGenerateLocalizationFiles(translations, languages)
elif targetName == "ios":
    iosGenerateLocalizationFiles(translations, languages)
    iosGenerateConstantsFiles(translations, languages)
elif targetName == "ios-swift":
    iosGenerateLocalizationFiles(translations, languages)
    iosGenerateSwiftConstantsFile(translations, languages)
else:
    print("ERROR: Unknown target")
    sys.exit(1)



# !/usr/bin/env python
# coding: utf-8

from googlesheettranslate.main import GoogleTranslationSheet


builder = GoogleTranslationSheet().EnabledProxy().builderOutputTarget("${localization}").builderFromGoogleSheet("${GOOGLETRANS}")
# builder = GoogleTranslationSheet().builderOutputTarget("${localization}").builderFromCSV("${TRANSLATION_F}")
builder.GetReader().overrideFileFormat("_{}.json", True)
builder.run("CN")
builder.run("EN")
builder.run("ZH")
builder.run("JP")
builder.run("TH")
builder.run("IN")
builder.run("KR")
builder.run("RU")
builder.run("AR")
builder.run("DE")
builder.run("ES")
builder.run("FR")
builder.run("IT")



# !/usr/bin/env python
# coding: utf-8
import os

from googlesheettranslate.main import GoogleTranslationSheet

ROOT = os.path.join(os.path.dirname(__file__))
sheetID = "fjosijfijsoeif"
gid = "fjsoaiejfoijseoifjo"

"""
builder = GoogleTranslationSheet().builderOutputTarget(ROOT).builderMeta(
    "https://docs.google.com/spreadsheets/d/e/{}/pubhtml?gid={}&single=true".format(sheetID, gid)
)
"""

builder = GoogleTranslationSheet().builderOutputTarget(ROOT).builderFromGoogleSheetMeta(sheetID, gid)

# builder.GetReader().overrideFileFormat("_{}.json", True)
builder.builderTransformers("Android")
builder.run("CN")
builder.run("EN")
builder.builderTransformers("i18n")
builder.run("CN")
builder.run("EN")



from .corehelper import *
from .itransformer import InterfaceTransform


# coding=utf8
# the above tag defines encoding for this document and is for Python 2.x compatibility


class Jsi18n(InterfaceTransform):
    def __init__(self):
        """ implementation of interface transformation """
        super().__init__("Jsi18n")

    def autoGeneratedTag(self) -> str:
        #  return "// AUTO-GENERATED - DO NOT EDIT THE LINES BELOW "
        return ""

    def autoFileName(self) -> str:
        return "_{}.json"

    def transformComment(self, comment: str) -> str:
        """comment replace"""
        return ""

    # You can manually specify the number of replacements by changing the 4th argument
    def transformKeyValue(self, key: str, value: str, isLast: bool = False) -> str:
        if self.isCommonKey(key):
            return self.transformComment(key)

        if len(key) == 0:
            return ""

        normalizedValue = RegexBoxNewLine(value)
        normalizedValue = RegexBoxDoubleQuote(normalizedValue)
        normalizedValue = RegexBoxDF(normalizedValue)
        normalizedValue = RegexBoxBR(normalizedValue)
        normalizedValue = RegexBoxStrAt(normalizedValue)
        normalizedValue = RegexBoxAmp(normalizedValue)

        line_template = ' "{}": "{}"{}'

        if key == "nan":
            return ""

        if isLast:
            return line_template.format(key, normalizedValue, "")
        else:
            return line_template.format(key, normalizedValue, ",")

    def wrap_file(self, input: str, newValues: list) -> list:
        return ["{"] + newValues + ["}"]



from .corehelper import *
from .itransformer import InterfaceTransform


# coding=utf8
# the above tag defines encoding for this document and is for Python 2.x compatibility


class Android(InterfaceTransform):
    def __init__(self):
        """ implementation of interface transformation """
        super().__init__("AndroidTransformer")
        self.id = ""

    def autoGeneratedTag(self) -> str:
        return "<!-- AUTO-GENERATED - DO NOT EDIT THE LINES BELOW-->"

    def autoFileName(self) -> str:
        return "values-{}.xml"

    def transformComment(self, comment: str) -> str:
        """comment replace"""
        return "<!-- {} -->".format(comment)

    # You can manually specify the number of replacements by changing the 4th argument
    def transformKeyValue(self, key: str, value: str, isLast: bool = False) -> str:
        if self.isCommonKey(key):
            return self.transformComment(key)

        if len(key) == 0:
            return ""

        normalizedValue = RegexBoxNewLine(value)
        normalizedValue = RegexBoxSingleQued(normalizedValue)
        normalizedValue = RegexBoxDoubleQuoteReverse(normalizedValue)
        normalizedValue = RegexBoxAt2String(normalizedValue)
        normalizedValue = RegexBoxSDF(normalizedValue)
        normalizedValue = RegexBoxAmp(normalizedValue)
        normalizedValue = RegexBoxu0A00(normalizedValue)
        normalizedValue = RegexBoxCodeDot3(normalizedValue)
        normalizedValue = RegexBoxCodeDot3(normalizedValue)
        normalizedValue = RegexBoxBR(normalizedValue)
        normalizedValue = RegexLinkCase(normalizedValue)

        line_template = '<string name="{}">{}</string>'
        line = line_template.format(key, normalizedValue)

        # currPos = line.find("%#$", 0)

        return line

    def wrap_file(self, input: str, newValues: list) -> list:

        return [
                   '<?xml version="1.0" encoding="utf-8"?>',
                   '<resources>'
               ] + newValues + [
                   '</resources>'
               ]



# !/usr/bin/env python
# coding: utf-8
import os

from googlesheettranslate.main import GoogleTranslationSheet

ROOT = os.path.join(os.path.dirname(__file__))
GOOGLETRANS = "https://docs.google.com/spreadsheets/d/e/2PACX-1vRHwRalwUDWbaIH2gU66lYnhf-Y0g7hxQxilnjTYnSkbVMAQNr6_pB_rwVrZUGX4huxM525w1U6JbA-/pubhtml?gid=863127413&single=true"
builder = GoogleTranslationSheet().EnabledProxy().builderOutputTarget(ROOT).builderFromGoogleSheet(GOOGLETRANS)
# builder = GoogleTranslationSheet().builderOutputTarget("${localization}").builderFromCSV("${TRANSLATION_F}")
builder.GetReader().overrideFileFormat("_{}.json", True)
builder.run("CN")
builder.run("EN")
builder.run("ZH")
builder.run("JP")
builder.run("TH")
builder.run("IN")
builder.run("KR")
builder.run("RU")
builder.run("AR")
builder.run("DE")
builder.run("ES")
builder.run("FR")
builder.run("IT")




import os

ANDROID_LOCALIZATION_DIR_NAME_EN = "res/values"
ANDROID_LOCALIZATION_DIR_NAME_MASK = "res/values-{0}"
ANDROID_LOCALIZATION_FILE_NAME = "strings.xml"

ANDROID_LOCALIZATION_HEADER = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<resources>\n"
ANDROID_LOCALIZATION_FORMAT = "<string name=\"{0}\">{1}</string>\n"
ANDROID_LOCALIZATION_FOOTER = "</resources>"

def androidGenerateLocalizationFiles(translations, languages):
    for languageId in range(0, len(languages)):
        language = languages[languageId]
        dirName = ANDROID_LOCALIZATION_DIR_NAME_EN
        if (language != "en"):
            dirName = ANDROID_LOCALIZATION_DIR_NAME_MASK.format(language)
        # Create localization directory if it does not exist.
        if (not os.path.exists(dirName)):
            print("Creating directory '{0}'".format(dirName))
            os.makedirs(dirName)
        filePath = dirName + "/" + ANDROID_LOCALIZATION_FILE_NAME
        print("Generating Android localization file '{0}'".format(filePath))
        with open(filePath, "w") as f:
            f.write(androidLocalization(translations, languageId))

def androidLocalization(translations, languageId):
    contents = ANDROID_LOCALIZATION_HEADER
    for tr in translations:
        # Ignore empty keys.
        if (tr.androidKey is None):
            continue
        # TODO: Add comments.
        contents += ANDROID_LOCALIZATION_FORMAT.format(tr.androidKey, tr.translations[languageId])
    contents += ANDROID_LOCALIZATION_FOOTER
    return contents



import os
import time
from typing import Iterable, Any

import pandas as pd

from .Err import TransformError
from .transformers.Android import Android
from .transformers.Jsi18n import Jsi18n
from .transformers.PyLan import PyLan

statement = 'End : {}, IO File {}'


class Reader:
    Transformers = {
        "i18n": Jsi18n,
        "Android": Android,
        "py": PyLan
    }

    def __init__(self):
        self.key = "KEY"
        self.column = "CN"
        self.row_index = 1
        self.transformerEngine = None
        self._output_file_format = None
        self._defaultEncoding = "utf8"
        self._output_key_lowercase = True
        self.__debug = False
        self.lines = list()
        self.target = ""
        self.useEngine("")

    def setDebug(self, debug: bool) -> "Reader":
        self.__debug = debug
        return self

    def setKey(self, _key: str) -> "Reader":
        """
        specification for the KEY column
        :param _key: KEY column in string
        :return:
        """
        self.key = _key
        return self

    def overrideFileFormat(self, format_file: str, forceLowercase: bool) -> "Reader":
        """
        overrider for the file format
        :param format_file:
        :param forceLowercase:
        :return:
        """
        self._output_file_format = format_file
        self._output_key_lowercase = forceLowercase
        return self

    def setLang(self, tag: str) -> "Reader":
        """
        specification for the Language column
        :param tag: it can be the short form of the language column key
        :return:
        """
        self.column = tag
        return self

    def setTarget(self, f: str) -> "Reader":
        """
        to save the translation at the specific file folder target
        :param f:
        :return:
        """
        self.target = f
        return self

    def useEngine(self, tag: str) -> "Reader":
        """
        using the engine for the reader to get up
        :param tag:
        :return:
        """
        if tag in self.Transformers:
            self.transformerEngine = self.Transformers[tag]()
        else:
            self.transformerEngine = self.Transformers["i18n"]()

        return self

    def startRow(self, s: int) -> "Reader":
        self.row_index = s
        return self

    def AppendCacheLine(self, info: str):
        """
        for debug purpose the rendering result on each line
        :param info: the line string
        :return:
        """
        if self.__debug:
            print(info)
        self.lines.append(info)

    def newSheet(self):
        """
        to remove the cache and start the newline
        :return:
        """
        self.lines = list()
        self._output_file_format = False

    def _getfilename(self) -> str:
        if self._output_key_lowercase:
            keyname = self.column.lower()
        else:
            keyname = self.column
        return os.path.join(self.target, self._output_file_format.format(keyname))

    def writeFile(self, content, filename):
        fo = open(filename, "w")
        fo.write(content)
        fo.close()
        print(statement.format(time.ctime(), filename))

    def SortAskOut(self):
        """
        self.writeFile("", self.exchange_data_output)
        with opens(self.downline_batch) as lines:
            for line in lines:
                num = line.translate(str.maketrans('', '', ' \n\t\r'))
                self.NewSort().TradeSortByNumber(num)
                file_object = open(self.exchange_data_output, 'a')
                if len(self.list_downline_people) > 0:
                    file_object.write("[{}]:\n".format(num))
                    file_object.write('\n'.join(self.list_downline_people))
                else:
                    file_object.write("[{}]: NO MEMBERS \n".format(num))
                file_object.close()"""

    def LoopExcel(self, input_file_path: str) -> "Reader":
        if not self.transformerEngine:
            raise TransformError
        if not self._output_file_format:
            self._output_file_format = self.transformerEngine.autoFileName()

        data = pd.read_excel(input_file_path)
        df = pd.DataFrame(data, columns=[self.key, self.column])
        print(f"size {df.size / 2}")
        for index, row in df.iterrows():
            # trim line
            raw_key = str(row[self.key])
            raw_value = str(row[self.column]).translate(str.maketrans('', '', '\n\t\r'))

            if index == 0:
                self.AppendCacheLine(self.transformerEngine.autoGeneratedTag())

            if index > 0:

                if self.transformerEngine.isCommonKey(raw_key):
                    print(f"is common now {index}")
                    continue

                self.AppendCacheLine(
                    self.transformerEngine.transformKeyValue(raw_key, raw_value, index == df.size / 2 - 1)
                )

        self.lines = self.transformerEngine.wrap_file("", self.lines)

        file = self._getfilename()
        self.writeFile("", file)
        file_io = open(file, 'a')
        for line in self.lines:
            file_io.write("{}\n".format(line))
        file_io.close()
        return self

    def LoopMatrix(self, reader: Iterable[Iterable[Any]]) -> "Reader":
        """
        enable the reader to start working
        :param reader:
        :return:
        """
        if not self.transformerEngine:
            raise TransformError
        if not self._output_file_format:
            self._output_file_format = self.transformerEngine.autoFileName()
        self.row_index = 0
        count = 0
        column_key = 0
        column_val = 0
        raw_key = ""
        raw_value = ""
        # print("{} - now".format(len(reader)))
        for row in reader:
            col = 0

            for rawcc in row:

                if count == self.row_index:
                    name = rawcc.strip()

                    if name == self.key:
                        column_key = col

                    if name == self.column:
                        print("checked - {}".format(name))
                        column_val = col

                if count > self.row_index:
                    name = rawcc.strip()
                    if col is column_key:
                        raw_key = name

                    if col is column_val:
                        raw_value = name

                col = col + 1

            if count == 0:
                self.AppendCacheLine(self.transformerEngine.autoGeneratedTag())

            if count > 0:
                self.AppendCacheLine(
                    self.transformerEngine.transformKeyValue(raw_key, raw_value, count == len(reader) - 1)
                )

            count = count + 1

        self.lines = self.transformerEngine.wrap_file("", self.lines)

        file = self._getfilename()
        self.writeFile("", file)
        file_io = open(file, 'a')
        for line in self.lines:
            file_io.write("{}\n".format(line))
        file_io.close()

        return self

    def LoopTable(self, reader: Iterable[Iterable[Any]]) -> "Reader":
        """
        enable the reader to start working
        :param reader:
        :return:
        """
        if not self.transformerEngine:
            raise TransformError
        if not self._output_file_format:
            self._output_file_format = self.transformerEngine.autoFileName()
        # self.row_index = 1
        count = 0
        column_key = 0
        column_val = 0
        raw_key = ""
        raw_value = ""
        # print("{} - now".format(len(reader)))
        for row in reader:
            col = 0

            for rawcc in row:

                if count == self.row_index:
                    name = rawcc.strip()

                    if name == self.key:
                        column_key = col

                    if name == self.column:
                        print("checked - {}".format(name))
                        column_val = col

                if count > self.row_index:
                    name = rawcc.strip()
                    if col is column_key:
                        raw_key = name

                    if col is column_val:
                        raw_value = name

                col = col + 1

            if count == 0:
                self.AppendCacheLine(self.transformerEngine.autoGeneratedTag())

            if count > 0:
                self.AppendCacheLine(
                    self.transformerEngine.transformKeyValue(raw_key, raw_value, count == len(reader) - 1)
                )

            count = count + 1

        self.lines = self.transformerEngine.wrap_file("", self.lines)

        file = self._getfilename()
        self.writeFile("", file)
        file_io = open(file, 'a')
        for line in self.lines:
            file_io.write("{}\n".format(line))
        file_io.close()

        return self



import re


def RegexBoxNewLine(value: str) -> str:
    subst = ""
    normalizedValue = ""
    r1 = r"%newline%"
    result = re.sub(r1, subst, value, 0, re.IGNORECASE)
    if result:
        normalizedValue = result
    else:
        normalizedValue = value

    return normalizedValue


def RegexBoxDoubleQuote(value: str) -> str:
    subst = "\\\\\""
    normalizedValue = ""
    r1 = r"\""
    result = re.sub(r1, subst, value, 0, re.IGNORECASE)
    if result:
        normalizedValue = result
    else:
        normalizedValue = value

    return normalizedValue


def RegexBoxSingleQuote(value: str) -> str:
    subst = "\\\\\""
    normalizedValue = ""
    r1 = r"\'"
    result = re.sub(r1, subst, value, 0, re.IGNORECASE)
    if result:
        normalizedValue = result
    else:
        normalizedValue = value

    return normalizedValue


def RegexBoxDoubleQuoteReverse(value: str) -> str:
    subst = '"'
    normalizedValue = ""
    r1 = r"\""
    result = re.sub(r1, subst, value, 0, re.IGNORECASE)
    if result:
        normalizedValue = result
    else:
        normalizedValue = value

    return normalizedValue


def RegexBoxSingleQued(value: str) -> str:
    subst = "\\'"
    normalizedValue = ""
    r1 = r"'"
    result = re.sub(r1, subst, value, 0, re.IGNORECASE)
    if result:
        normalizedValue = result
    else:
        normalizedValue = value

    return normalizedValue


def RegexBoxAmp(value: str) -> str:
    subst = "&amp;"
    normalizedValue = ""
    r1 = r"&"
    result = re.sub(r1, subst, value, 0, re.IGNORECASE)
    if result:
        normalizedValue = result
    else:
        normalizedValue = value

    return normalizedValue


def RegexBoxSDF(value: str) -> str:
    subst = "%#$$$1"
    normalizedValue = ""
    r1 = r"%([sdf])"
    result = re.sub(r1, subst, value, 0, re.IGNORECASE)
    if result:
        normalizedValue = result
    else:
        normalizedValue = value

    return normalizedValue


def RegexBoxStrAt(value: str) -> str:
    normalizedValue = ""
    subst = "%@"
    r1 = r"%s"
    result = re.sub(r1, subst, value, 0, re.IGNORECASE)
    if result:
        normalizedValue = result
    else:
        normalizedValue = value

    return normalizedValue


def RegexBoxAt2String(value: str) -> str:
    normalizedValue = ""
    subst = "%s"
    r1 = r"%@"
    result = re.sub(r1, subst, value, 0, re.IGNORECASE)
    if result:
        normalizedValue = result
    else:
        normalizedValue = value

    return normalizedValue


def RegexBoxu0A00(value: str) -> str:
    normalizedValue = ""
    subst = "\\\u00A0"
    r1 = r"\u00A0"
    result = re.sub(r1, subst, value, 0, re.IGNORECASE | re.MULTILINE)
    if result:
        normalizedValue = result
    else:
        normalizedValue = value

    return normalizedValue


def RegexBoxCodeDot3(value: str) -> str:
    """
    do it a second time to fix values... ...like this (don't ask)
    @source: https://github.com/tntdigital/localize-with-spreadsheet/blob/master/core/Transformer.js
    @type {*}
    :param value:
    :return:
    """
    normalizedValue = ""
    subst = "$1&#8230;$3"
    r1 = r"([^\.]|^)(\.{3})([^\.]|$)"
    result = re.sub(r1, subst, value, 0, re.IGNORECASE)
    if result:
        normalizedValue = result
    else:
        normalizedValue = value

    return normalizedValue


def RegexBoxBR(value: str) -> str:
    normalizedValue = ""
    subst = "<br>"
    r1 = r"<BR>"
    result = re.sub(r1, subst, value, 0, re.MULTILINE | re.IGNORECASE)
    if result:
        normalizedValue = result
    else:
        normalizedValue = value

    return normalizedValue


def RegexBoxDF(value: str) -> str:
    subst = "%$1"
    normalizedValue = ""
    r1 = r"%([@df])"
    result = re.sub(r1, subst, value, 0, re.IGNORECASE)
    if result:
        normalizedValue = result
    else:
        normalizedValue = value

    return normalizedValue


def RegexLinkCase(value: str) -> str:
    regex = r"href=\"(.*?)\""
    matches = re.finditer(regex, value.lower(), re.MULTILINE)
    matched = False
    for matchNum, match in enumerate(matches):
        matched = True

    if matched:
        normalizedValue = "<![CDATA[{}]]>".format(value)
    else:
        normalizedValue = value

    return normalizedValue




import gspread

ERR_MSG_SHEET = """
ERROR: Could not find sheet named '{0}'. Make sure it exists
"""

ERR_MSG_SPREADSHEET = """
ERROR: Could not find spreadsheet named '{0}'.
Make sure:
* it exists
* you have added your service account email as the document editor in the document sharing settings
"""

class Spreadsheet(object):
    def __init__(self, gspreadClient):
        self.client = gspreadClient
        self.document = None
    def open(self, spreadsheetKey):
        try:
            self.document = self.client.open_by_key(spreadsheetKey)
        except gspread.exceptions.SpreadsheetNotFound:
            print(ERR_MSG_SPREADSHEET.format(spreadsheetKey))
            raise
    def sheet(self, sheetName):
        try:
            return self.document.worksheet(sheetName)
        except:
            print(ERR_MSG_SHEET.format(sheetName))
            raise




from abc import abstractmethod, ABCMeta


class InterfaceTransform(metaclass=ABCMeta):

    def __init__(self, name: str = "", args: any = None):
        self.name = name

    def __eq__(self, profile: "InterfaceTransform"):
        return self.name == profile.name  # I made it up the id property.

    def __hash__(self):
        return hash(self.name)

    def isCommonKey(self, key: str) -> bool:
        return key.find(" ", 0) > -1  or key[0:1].isupper()

    @classmethod
    def __subclasshook__(cls, C):
        if C.__abstractmethods__:
            print(C.__abstractmethods__)
            return False
        else:
            return True

    @abstractmethod
    def autoFileName(self) -> str:
        """Generation of language file format"""
        pass

    @abstractmethod
    def autoGeneratedTag(self) -> str:
        """AUTO-GENERATED - DO NOT EDIT THE LINES BELOW"""
        pass

    @abstractmethod
    def transformComment(self, comment: str) -> str:
        """transform for the comment inline.

        write it as comment line
        """
        pass

    @abstractmethod
    def transformKeyValue(self, key: str, value: str, isLast: bool = False) -> str:
        """transform the key and value

        transform the key for each line
        """
        pass

    @abstractmethod
    def wrap_file(self, input: str, newValues: list) -> list:
        """ transform the input to output

        insert the format of the file from the start to the end
        """
        pass



from googlesheettranslate.googlesheettech.modu.Translation import Translation

CFG_KEY_ID = 0
CFG_VALUE_ID = 1
CFG_KEY_VALUE_COLUMNS_NB = 2


def configurationFromPage(page):
    cfg = {}
    rawValues = page.get_all_values()
    for row in rawValues:
        key = row[CFG_KEY_ID]
        # Only take those rows that
        # * have key value pairs
        # * have keys
        if (len(key) and (len(row) >= CFG_KEY_VALUE_COLUMNS_NB)):
            value = row[CFG_VALUE_ID]
            cfg[key] = value
    return cfg


def parsePage(page, cfg):
    # Get raw page values.
    raw = page.get_all_values()

    translationsColumnId = int(cfg["TRANSLATION_COLUMN"]) - 1

    # Get list of languages.
    languagesRowId = int(cfg["LANGUAGES_ROW"]) - 1
    langRow = raw[languagesRowId]
    languagesNb = len(langRow)
    languages = []
    for columnId in range(translationsColumnId, languagesNb):
        languages.append(raw[languagesRowId][columnId])

    translationRowId = int(cfg["TRANSLATION_ROW"]) - 1
    # Comments column ids.
    commentKeyColumnId = int(cfg["COMMENT_KEY_COLUMN"]) - 1
    groupCommentKeyColumnId = int(cfg["GROUP_COMMENT_KEY_COLUMN"]) - 1
    # Key column ids.
    androidKeyColumnId = int(cfg["ANDROID_KEY_COLUMN"]) - 1
    iosKeyColumnId = int(cfg["IOS_KEY_COLUMN"]) - 1

    # Parse translations.
    translations = []
    for rowId in range(0, len(raw)):
        # Skip non-translation rows.
        if (rowId < translationRowId):
            continue
        tr = Translation()
        # Comment keys.
        comment = raw[rowId][commentKeyColumnId]
        tr.comment = comment if len(comment) else None
        groupComment = raw[rowId][groupCommentKeyColumnId]
        tr.groupComment = groupComment if len(groupComment) else None
        # Platform keys.
        androidKey = raw[rowId][androidKeyColumnId]
        tr.androidKey = androidKey if len(androidKey) else None
        iosKey = raw[rowId][iosKeyColumnId]
        tr.iosKey = iosKey if len(iosKey) else None
        # Get translations.
        for columnId in range(translationsColumnId, languagesNb):
            tr.translations.append(raw[rowId][columnId])
        translations.append(tr)

    return (languages, translations)




import os

IOS_LOCALIZATION_DIR_NAME_MASK = u"{0}.lproj"
IOS_LOCALIZATION_FILE_NAME = u"Localizable.strings"

IOS_LOCALIZATION_GROUP_COMMENT_FORMAT = u"/* {0} */\n"
IOS_LOCALIZATION_FORMAT = u"\"{0}\" = \"{1}\";\n"

IOS_CONSTANTS_HEADER_FILE_NAME = u"LocalizationConstants.h"
IOS_CONSTANTS_SOURCE_FILE_NAME = u"LocalizationConstants.m"

IOS_CONSTANTS_HEADER_HEADER = u"#import <Foundation/Foundation.h>\n\n"
IOS_CONSTANTS_HEADER_CONST_FORMAT = u"extern NSString * const {0};\n"
IOS_CONSTANTS_HEADER_DESC_START_FORMAT = u"\n/*!\n"
IOS_CONSTANTS_HEADER_DESC_END_FORMAT = u"*/\n"
IOS_CONSTANTS_HEADER_COMM_FORMAT = u"* {0}\n\n"
IOS_CONSTANTS_HEADER_LANG_FORMAT = u"* @b {0}@: {1}\n\n"

IOS_CONSTANTS_SOURCE_HEADER = u"#import \"LocalizationConstants.h\"\n\n"
IOS_CONSTANTS_SOURCE_FORMAT = u"NSString * const {0} = @\"{1}\";\n"

IOS_CONSTANTS_SWIFT_FILE_NAME = u"LocalizationConstants.swift"
IOS_CONSTANTS_SWIFT_ENUM_HEADER = u"import Foundation\n\nenum L10n {\n"
IOS_CONSTANTS_SWIFT_ENUM_ITEM_FORMAT = u"\tcase {0}\n"
IOS_CONSTANTS_SWIFT_ENUM_FOOTER = u"}\n\n"
IOS_CONSTANTS_SWIFT_EXT_HEADER = u"""
extension L10n: CustomStringConvertible {
\tvar description: String { return self.string }

\tvar string: String {
\t\tswitch self {
"""
IOS_CONSTANTS_SWIFT_EXT_ITEM_FORMAT = u"\t\t\tcase .{0}:\n\t\t\t\treturn L10n.tr(key: \"{1}\")\n"
IOS_CONSTANTS_SWIFT_EXT_FOOTER = u"""
\t\t}
\t}

\tprivate static func tr(key: String, _ args: CVarArg...) -> String {
\t\tlet format = NSLocalizedString(key, bundle: Bundle(for: BundleToken.self), comment: "")
\t\treturn String(format: format, locale: Locale.current, arguments: args)
\t}
}

func tr(_ key: L10n) -> String {
\treturn key.string
}

private final modu BundleToken {}
"""

def iosConstants(translations, languages):
    header = IOS_CONSTANTS_HEADER_HEADER
    source = IOS_CONSTANTS_SOURCE_HEADER
    for tr in translations:
        # Ignore empty keys.
        if (tr.iosKey is None):
            continue
        # Constant description.
        header += IOS_CONSTANTS_HEADER_DESC_START_FORMAT
        # Comment.
        if (tr.comment):
            header += IOS_CONSTANTS_HEADER_COMM_FORMAT.format(tr.comment)
        for languageId in range(0, len(languages)):
            language = languages[languageId]
            header += IOS_CONSTANTS_HEADER_LANG_FORMAT.format(language, tr.translations[languageId])
        header += IOS_CONSTANTS_HEADER_DESC_END_FORMAT
        # Constant itself.
        constant = "tr" + tr.iosKey.replace(".", "")
        header += IOS_CONSTANTS_HEADER_CONST_FORMAT.format(constant)
        source += IOS_CONSTANTS_SOURCE_FORMAT.format(constant, tr.iosKey)
    return (header, source)

def iosConstantsSwift(translations, languages):
    enum = IOS_CONSTANTS_SWIFT_ENUM_HEADER
    ext = IOS_CONSTANTS_SWIFT_EXT_HEADER
    for tr in translations:
        # Ignore empty keys.
        if (tr.iosKey is None):
            continue
        # TODO: Constant description.
        # Constant itself.
        constant = tr.iosKey.replace(".", "")
        enum += IOS_CONSTANTS_SWIFT_ENUM_ITEM_FORMAT.format(constant)
        ext += IOS_CONSTANTS_SWIFT_EXT_ITEM_FORMAT.format(constant, tr.iosKey)
    enum += IOS_CONSTANTS_SWIFT_ENUM_FOOTER
    ext += IOS_CONSTANTS_SWIFT_EXT_FOOTER
    result = enum + ext
    return result

def iosGenerateConstantsFiles(translations, languages):
    (header, source) = iosConstants(translations, languages)
    headerFileName = IOS_CONSTANTS_HEADER_FILE_NAME
    print("Generating iOS constants file '{0}'".format(headerFileName))
    with open(headerFileName, "w") as f:
        f.write(header.encode("utf-8"))
    sourceFileName = IOS_CONSTANTS_SOURCE_FILE_NAME
    print("Generating iOS constants file '{0}'".format(sourceFileName))
    with open(sourceFileName, "w") as f:
        f.write(source)

def iosGenerateLocalizationFiles(translations, languages):
    for languageId in range(0, len(languages)):
        language = languages[languageId]
        dirName = IOS_LOCALIZATION_DIR_NAME_MASK.format(language)
        # Create localization directory if it does not exist.
        if (not os.path.exists(dirName)):
            print("Creating directory '{0}'".format(dirName))
            os.makedirs(dirName)
        filePath = dirName + "/" + IOS_LOCALIZATION_FILE_NAME
        print("Generating iOS localization file '{0}'".format(filePath))
        with open(filePath, "w") as f:
            f.write(iosLocalization(translations, languageId))

def iosGenerateSwiftConstantsFile(translations, languages):
    source = iosConstantsSwift(translations, languages)
    sourceFileName = IOS_CONSTANTS_SWIFT_FILE_NAME
    print("Generating iOS constants file '{0}'".format(sourceFileName))
    with open(sourceFileName, "w") as f:
        f.write(source)

def iosLocalization(translations, languageId):
    contents = ""
    for tr in translations:
        # Ignore empty keys.
        if (tr.iosKey is None):
            continue
        if (tr.groupComment):
            contents += IOS_LOCALIZATION_GROUP_COMMENT_FORMAT.format(tr.groupComment)
        contents += IOS_LOCALIZATION_FORMAT.format(tr.iosKey, tr.translations[languageId])
    return contents.encode("utf-8")



#!/usr/bin/env python
# --------------------------------------------------------------------
# Copyright (c) EXPE. All rights reserved.
# Licensed under the MIT License.
# See License.txt in the project root for license information.
# --------------------------------------------------------------------

"""
    setup
    =====

    A Python API for interacting with GoogleSheet

    :copyright: © 2020 by the EXPE.
    :license: MIT License
"""

import codecs
import os
import platform

from setuptools import (
    find_packages,
    setup,
)

py_version = platform.python_version()

f = codecs.open('version', 'r', 'utf-8-sig')
line = f.readline()
f.close()
PACKAGE_VERSION = str(line)

EXTRAS_REQUIRE = {
    'tester': [
        'coverage',
        'pep8',
        'pyflakes',
        'pylint',
        'pytest-cov'
    ],

    'docs': [
        "mock",
        "sphinx-better-theme>=0.1.4",
        "click>=5.1",
        "configparser==3.5.0",
        "contextlib2>=0.5.4",
        "py-solc>=0.4.0",
        "pytest>=2.7.2",
        "sphinx",
        "pdoc3",
        "sphinx_rtd_theme>=0.1.9",
        "toposort>=1.4",
        "urllib3",
        "wheel >= 0.31.0"
    ],

    'dev': [
        "bumpversion",
        "flaky>=3.3.0",
        "hypothesis>=3.31.2",
        "pytest>=3.5.0,<4",
        "pytest-mock==1.*",
        "pytest-pythonpath>=0.3",
        "pytest-watch==4.*",
        "pytest-xdist==1.*",
        "setuptools>=38.6.0",
        "tox>=1.8.0",
        "twine >= 1.11.0",
        "tqdm",
        "when-changed"
    ]

}

EXTRAS_REQUIRE['dev'] = (
        EXTRAS_REQUIRE['tester'] +
        EXTRAS_REQUIRE['docs'] +
        EXTRAS_REQUIRE['dev']
)

install_requires = [
    "bs4",
    "requests>=2.16.0,<3.0.0",
    "base58",
    'attrdict',
]

this_dir = os.path.dirname(__file__)
readme_filename = os.path.join(this_dir, 'README.md')

with open(readme_filename) as f:
    PACKAGE_LONG_DESCRIPTION = f.read()

setup(
    name='googlesheettranslate',
    version=PACKAGE_VERSION,
    description='Non credential proved url scrapper for google sheet',
    long_description=PACKAGE_LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    keywords='google sheet cli sdk',
    url='https://gitee.com/jjhoc/sheet-localization-py',
    author='Shodan Vault & Heskemo',
    author_email='steein.shamsudin@gmail.com',
    license='MIT License',
    zip_safe=False,
    python_requires='>=3.5,<=4',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    packages=find_packages(exclude=['examples', 'private']),
    include_package_data=True,
    install_requires=install_requires,
    tests_require=EXTRAS_REQUIRE['tester'],
    extras_require=EXTRAS_REQUIRE,
)



#!/usr/bin/env python
# --------------------------------------------------------------------
# Copyright (c) iEXBase. All rights reserved.
# Licensed under the MIT License.
# See License.txt in the project root for license information.
# --------------------------------------------------------------------

import pkg_resources
import sys


if sys.version_info < (3, 5):
    raise EnvironmentError("Python 3.5 or above is required")

__version__ = pkg_resources.get_distribution("googlesheettranslate").version

__all__ = [
    '__version__',
]



# !/usr/bin/env python
# coding: utf-8
import os

from googlesheettranslate.main import GoogleTranslationSheet

ROOT = os.path.join(os.path.dirname(__file__))

builder = GoogleTranslationSheet().builderOutputTarget(ROOT).builderFromCSV("tr_csv.csv")

# builder.GetReader().overrideFileFormat("_{}.json", True)
builder.builderTransformers("Android")
builder.run("CN")
builder.run("EN")
builder.run("RU")

builder.builderTransformers("i18n")
builder.run("RU")
builder.run("FR")
builder.run("EN")
